from setuptools import setup, find_packages

setup(
    name='cv-lab-aurct',
    version='0.1',
    packages=find_packages(),
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',  # Adjust based on your markup type
)
